FlutterDistributor class

Constructors

FlutterDistributor()

Properties

displayName String
The display name of the package
finalinherited
distributeOptions → DistributeOptions
Get the distribute options
no setterinherited
globalVariables Map<String, String>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
packageName String
The name of the package
finalinherited
pubspec → Pubspec
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkVersion() Future<CheckVersionResult>
Check the version of the package
inherited
getCurrentVersion() Future<String?>
Get the current version of the package
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
package(String platform, List<String> targets, {String? channel, String? artifactName, required bool cleanBeforeBuild, required Map<String, dynamic> buildArguments, Map<String, String>? variables}) Future<List<MakeResult>>
Package an application for a specific platform and target
inherited
publish(FileSystemEntity fileSystemEntity, List<String> targets, {Map<String, dynamic>? publishArguments, Map<String, String>? variables}) Future<List<PublishResult>>
Publish an application to a third party provider
inherited
release(String name, {required List<String> jobNameList, required List<String> skipJobNameList, required bool cleanBeforeBuild}) Future<void>
Release an application to a third party provider
inherited
toString() String
A string representation of this object.
inherited
upgrade() Future<void>
Upgrade the package to the latest version
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited